==> TundereBird-0.24.tar.bz2: TundereBird-0.24/core/Smdn.Net.Imap4/Smdn.Net.Imap4/ImapMailboxList.cs <==
// 
// Author:
//       smdn <smdn@mail.invisiblefulmoon.net>
// 
// Copyright (c) 2008-2010 smdn
// 
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to deal
// in the Software without restriction, including without limitation the rights
// to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
// copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
// 
// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.
// 
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
// THE SOFTWARE.

using System;

namespace Smdn.Net.Imap4 {
  public class ImapMailboxList {
    public class ListExtendedChildInfo {
      public bool Subscribed {
        get; internal set;
      }

      internal ListExtendedChildInfo()
      {
        Subscribed = false;
      }
    }

    public ImapMailboxFlagList NameAttributes {
      get; private set;
    }

    public string HierarchyDelimiter {
      get; private set;
    }

    public string Name {
      get; private set;
    }

    public ListExtendedChildInfo ChildInfo {
      get; internal set;
    }

    public ImapMailboxList(ImapMailboxFlagList nameAttributes, string hierarchyDelimiter, string name)
    {
      if (nameAttributes == null)
        throw new ArgumentNullException("nameAttributes");
      if (name == null)
        throw new ArgumentNullException("name");

      this.NameAttributes = nameAttributes;
      this.HierarchyDelimiter = hierarchyDelimiter;
      this.Name = name;

      this.ChildInfo = null;
    }

    public override string ToString()
    {
      return string.Format("{{NameAttributes={0}, HierarchyDelimiter={1}, Name={2}}}", NameAttributes, HierarchyDelimiter, Name);
    }
  }
}

==> TundereBird-0.28.tar.bz2: TundereBird-0.28/core/Smdn.Net.Imap4/Smdn.Net.Imap4/ImapMailboxList.cs <==
// 
// Author:
//       smdn <smdn@mail.invisiblefulmoon.net>
// 
// Copyright (c) 2008-2010 smdn
// 
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to deal
// in the Software without restriction, including without limitation the rights
// to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
// copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
// 
// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.
// 
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
// THE SOFTWARE.

using System;

namespace Smdn.Net.Imap4 {
  public class ImapMailboxList {
    public class ListExtendedChildInfo {
      public bool Subscribed {
        get; internal set;
      }

      internal ListExtendedChildInfo()
      {
        Subscribed = false;
      }
    }

    public IImapMailboxFlagSet NameAttributes {
      get; private set;
    }

    public string HierarchyDelimiter {
      get; private set;
    }

    public string Name {
      get; private set;
    }

    public ListExtendedChildInfo ChildInfo {
      get; internal set;
    }

    public ImapMailboxList(IImapMailboxFlagSet nameAttributes, string hierarchyDelimiter, string name)
    {
      if (nameAttributes == null)
        throw new ArgumentNullException("nameAttributes");
      if (name == null)
        throw new ArgumentNullException("name");

      this.NameAttributes = nameAttributes;
      this.HierarchyDelimiter = hierarchyDelimiter;
      this.Name = name;

      this.ChildInfo = null;
    }

    public override string ToString()
    {
      return string.Format("{{NameAttributes={0}, HierarchyDelimiter={1}, Name={2}}}", NameAttributes, HierarchyDelimiter, Name);
    }
  }
}
